pub type Result<T> = Result<T, CurrencyError>;Expand description
Type alias for Results using our custom error type This is a common Rust pattern - makes code cleaner
Aliased Type
pub enum Result<T> {
Ok(T),
Err(CurrencyError),
}pub type Result<T> = Result<T, CurrencyError>;Type alias for Results using our custom error type This is a common Rust pattern - makes code cleaner
pub enum Result<T> {
Ok(T),
Err(CurrencyError),
}